@@ -758,8 +758,17 @@ class LessonStatistics(AbstractStatistics):
 
 class IntervalStatistics(AbstractStatistics):
     def get_keys(self, all_keys=False):
+        # FIXME we have to check that all keys are integers, and filter
+        # out those that are not. I don't know how, but I ended up with
+        # the key None inserted into the database.
+        def isinteger(s):
+            try:
+                int(s)
+                return True
+            except ValueError:
+                return False
         v = AbstractStatistics.get_keys(self, all_keys)
-        return [int(x) for x in v]
+        return [int(x) for x in v if isinteger(x)]
     def key_to_pretty_name(self, key):
         return utils.int_to_intervalname(int(key), 1, 1)
 
