@@ -20,5 +20,5 @@ print "\n".join(textwrap.wrap(
 
 print
 print "filename:", sys.argv[1]
-print "hash value:", statistics.hash_of_lessonfile(unicode(sys.argv[1]))
+print "    replaces = \"%s\"" % statistics.hash_of_lessonfile(unicode(sys.argv[1]))
 print
